%bcond_with     cifs
%bcond_with     ftp
%bcond_with     hadoop
%bcond_with     mina

Name:           apache-commons-vfs
Version:        2.9.0
Release:        %mkrel 2
Group:          Development/Java
Summary:        Commons Virtual File System
License:        ASL 2.0
BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch

URL:            https://commons.apache.org/proper/commons-vfs/
Source0:        https://archive.apache.org/dist/commons/vfs/source/commons-vfs-%{version}-src.tar.gz
Source1:        https://archive.apache.org/dist/commons/vfs/source/commons-vfs-%{version}-src.tar.gz.asc
Source2:        https://downloads.apache.org/commons/KEYS

# Migrate from the old commons-httpclient, which is no longer available in
# Fedora, to the newer httpcomponents httpclient.
Patch0:         %{name}-httpclient.patch

BuildRequires:  gnupg2
BuildRequires:  maven-local
BuildRequires:  mvn(com.jcraft:jsch)
BuildRequires:  mvn(com.sun.mail:jakarta.mail)
BuildRequires:  mvn(commons-codec:commons-codec)
BuildRequires:  mvn(commons-io:commons-io)
BuildRequires:  mvn(commons-logging:commons-logging)
BuildRequires:  mvn(commons-net:commons-net)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.ant:ant)
BuildRequires:  mvn(org.apache.commons:commons-collections4)
BuildRequires:  mvn(org.apache.commons:commons-compress)
BuildRequires:  mvn(org.apache.commons:commons-lang3)
BuildRequires:  mvn(org.apache.commons:commons-parent:pom:)
BuildRequires:  mvn(org.apache.httpcomponents:httpclient)
BuildRequires:  mvn(org.apache.httpcomponents:httpcore-nio)
BuildRequires:  mvn(org.apache.logging.log4j:log4j-core)
BuildRequires:  mvn(org.apache.logging.log4j:log4j-slf4j-impl)
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-assembly-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-surefire-plugin)
BuildRequires:  mvn(org.apache.sshd:sshd-core)
BuildRequires:  mvn(org.bouncycastle:bcprov-jdk16)
BuildRequires:  mvn(org.mockito:mockito-core)
BuildRequires:  mvn(org.slf4j:jcl-over-slf4j)
BuildRequires:  mvn(org.slf4j:slf4j-api)
%if %{with hadoop}
BuildRequires:  mvn(javax.ws.rs:jsr311-api)
BuildRequires:  mvn(org.apache.hadoop:hadoop-common)
BuildRequires:  mvn(org.apache.hadoop:hadoop-hdfs)
BuildRequires:  mvn(org.apache.hadoop:hadoop-hdfs-client)
%endif
%if %{with ftp}
BuildRequires:  mvn(org.apache.ftpserver:ftpserver-core)
%endif
%if %{with cifs}
BuildRequires:  mvn(jcifs:jcifs)
%endif
%if %{with mina}
BuildRequires:  mvn(org.apache.mina:mina-core)
%endif

Provides:       %{name}2 = %{version}-%{release}

%description
Commons VFS provides a single API for accessing various file systems.
It presents a uniform view of the files from various sources, such as
the files on local disk, on an HTTP server, or inside a Zip archive.

Some of the features of Commons VFS are:
* A single consistent API for accessing files of different types.
* Support for numerous file system types.
* Caching of file information.  Caches information in-JVM, and
  optionally can cache remote file information on the local file
  system (replicator).
* Event delivery.
* Support for logical file systems made up of files from various file
  systems.
* Utilities for integrating Commons VFS into applications, such as a
  VFS-aware ClassLoader and URLStreamHandlerFactory.
* A set of VFS-enabled Ant tasks.

%package       ant
Summary:       Development files for Commons VFS
Requires:      %{name} = %{version}-%{release}
Requires:      ant

%description   ant
This package enables support for the Commons VFS ant tasks.

%package       examples
Summary:       Commons VFS Examples
Requires:      %{name} = %{version}-%{release}

%description   examples
VFS is a Virtual File System library - Examples.

%package       project
Summary:       Commons VFS Parent POM

%description   project
Commons VFS Parent POM.

%javadoc_package

%prep
%{gpgverify} --data=%{SOURCE0} --signature=%{SOURCE1} --keyring=%{SOURCE2}
%autosetup -n commons-vfs-%{version} -p1

# Not needed for RPM builds
%pom_xpath_remove //pom:reporting
%pom_remove_plugin :apache-rat-plugin
%pom_remove_plugin :japicmp-maven-plugin
%pom_remove_plugin :maven-checkstyle-plugin
%pom_remove_plugin :maven-pmd-plugin
%pom_remove_plugin :maven-project-info-reports-plugin
%pom_remove_plugin :spotbugs-maven-plugin

# Disable unwanted module
%pom_disable_module commons-vfs2-distribution

# Fix ant gId
%pom_change_dep -r :ant org.apache.ant:

# Remove webdav client (jackrabbit not packaged)
%pom_remove_dep -r org.apache.jackrabbit:
%pom_disable_module commons-vfs2-jackrabbit1
%pom_disable_module commons-vfs2-jackrabbit2

# Remove http3 client.  It needs the old commons-httpclient, which is no
# longer available in Fedora.  We support the http4 client.
%pom_remove_dep -r commons-httpclient:commons-httpclient
rm -r commons-vfs2/src/{main,test}/java/org/apache/commons/vfs2/provider/http
rm -r commons-vfs2/src/{main,test}/java/org/apache/commons/vfs2/provider/https

# Remove http5 client (httpclient5 not packaged)
%pom_remove_dep -r org.apache.httpcomponents.client5:httpclient5
rm -r commons-vfs2/src/{main,test}/java/org/apache/commons/vfs2/provider/http5
rm -r commons-vfs2/src/{main,test}/java/org/apache/commons/vfs2/provider/http5s

# hadoop has been retired
%if %{without hadoop}
%pom_remove_dep -r org.apache.hadoop
%pom_remove_dep -r javax.ws.rs
rm -r commons-vfs2/src/{main,test}/java/org/apache/commons/vfs2/provider/hdfs
%endif

# ftpserver is not available
%if %{without ftp}
%pom_remove_dep -r :ftpserver-core
rm -r commons-vfs2/src/{main,test}/java/org/apache/commons/vfs2/provider/ftps
%endif

# jcifs not packaged and also export controlled in the US
%if %{without cifs}
%pom_remove_dep :jcifs
%endif

# mina is not available
%if %{without mina}
%pom_remove_dep :mina-core
%endif

# Fix installation directory and symlink
%mvn_file :commons-vfs2 %{name}
%mvn_file :commons-vfs2 %{name}2
%mvn_file :commons-vfs2 commons-vfs
%mvn_file :commons-vfs2 commons-vfs2
%mvn_file :commons-vfs2-examples %{name}-examples
%mvn_file :commons-vfs2-examples %{name}2-examples
%mvn_file :commons-vfs2-examples commons-vfs-examples
%mvn_file :commons-vfs2-examples commons-vfs2-examples

%mvn_alias :commons-vfs2 "org.apache.commons:commons-vfs" "commons-vfs:commons-vfs"
%mvn_alias :commons-vfs2-examples "org.apache.commons:commons-vfs-examples" "commons-vfs:commons-vfs-examples"

%build
%mvn_build -sf

%install
%mvn_install

mkdir -p %{buildroot}%{_sysconfdir}/ant.d
echo "ant commons-logging commons-vfs" > commons-vfs
install -p -m 644 commons-vfs %{buildroot}%{_sysconfdir}/ant.d/commons-vfs

%files -f .mfiles-commons-vfs2
%doc README.md RELEASE-NOTES.txt
%license LICENSE.txt NOTICE.txt

%files examples -f .mfiles-commons-vfs2-examples

%files project -f .mfiles-commons-vfs2-project
%license LICENSE.txt NOTICE.txt

%files ant
%config(noreplace) %{_sysconfdir}/ant.d/commons-vfs


%changelog
* Sun Jun 29 2025 umeabot <umeabot> 2.9.0-2.mga10
+ Revision: 2223125
- Mageia 10 Mass Rebuild

* Tue May 21 2024 ns80 <ns80> 2.9.0-1.mga10
+ Revision: 2065643
- new version 2.9.0 for java 21
+ neoclust <neoclust>
- Not used anymore

* Sun Feb 16 2020 umeabot <umeabot> 2.4.1-2.mga8
+ Revision: 1536206
- Mageia 8 Mass Rebuild

* Tue Oct 15 2019 daviddavid <daviddavid> 2.4.1-1.mga8
+ Revision: 1453704
- Update to version 2.4.1

* Wed Jul 24 2019 daviddavid <daviddavid> 2.1-3.mga8
+ Revision: 1423750
- Disable hadoop support by default

* Wed Dec 12 2018 daviddavid <daviddavid> 2.1-2.mga7
+ Revision: 1340719
- rebuild against fixed apache-commons-parent (fixes osgi meta)

* Mon Dec 10 2018 daviddavid <daviddavid> 2.1-1.mga7
+ Revision: 1339717
- new version: 2.1 (sync with fc29)

* Tue Sep 18 2018 umeabot <umeabot> 2.0-22.mga7
+ Revision: 1261227
- Mageia 7 Mass Rebuild

* Tue Sep 18 2018 umeabot <umeabot> 2.0-21.mga7
+ Revision: 1260039
- Mageia 7 Mass Rebuild

* Tue Sep 18 2018 umeabot <umeabot> 2.0-20.mga7
+ Revision: 1259788
- Mageia 7 Mass Rebuild

* Wed May 17 2017 neoclust <neoclust> 2.0-19.mga6
+ Revision: 1102468
- Rebuild against fixed apache-parent

* Wed Mar 02 2016 neoclust <neoclust> 2.0-18.mga6
+ Revision: 982342
- Second rebuild of the java stack

* Sun Feb 21 2016 neoclust <neoclust> 2.0-17.mga6
+ Revision: 975486
- First rebuild of the java stack
- sync package apache-commons-vfs with fedora
- imported package apache-commons-vfs

* Fri Dec 26 2014 pterjan <pterjan> 2.0-13.mga5
+ Revision: 806031
- Update BuildRequires
+ dmorgan <dmorgan>
- Rebuild against java stack

* Thu Dec 25 2014 pterjan <pterjan> 2.0-10.mga5
+ Revision: 805751
- Clean rebuild
- Update BuildRequires
- Sync with Fedora 21
+ dmorgan <dmorgan>
- Restore from Obsolete
+ sander85 <sander85>
- Depends on broken java stack

* Wed Oct 15 2014 umeabot <umeabot> 2.0-8.mga5
+ Revision: 747784
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.0-7.mga5
+ Revision: 677825
- Mageia 5 Mass Rebuild

* Tue Dec 24 2013 dmorgan <dmorgan> 2.0-6.mga4
+ Revision: 560509
- Disable tests

* Tue Oct 22 2013 umeabot <umeabot> 2.0-5.mga4
+ Revision: 545689
- Mageia 4 Mass Rebuild

* Wed Oct 16 2013 dmorgan <dmorgan> 2.0-4.mga4
+ Revision: 501566
- Build with xmvn

* Fri Jan 11 2013 umeabot <umeabot> 2.0-3.mga3
+ Revision: 345822
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Sep 12 2012 dmorgan <dmorgan> 2.0-2.mga3
+ Revision: 292635
- Clean spec file

* Wed Oct 05 2011 dmorgan <dmorgan> 2.0-1.mga2
+ Revision: 151883
- Fix groups
- Clean spec file
+ gil <gil>
- edit spec file
- imported package apache-commons-vfs


* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0-16
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Jan 29 2015 gil cattaneo <puntogil@libero.it> 2.0-15
- introduce license macro

* Wed Jul 30 2014 Mikolaj Izdebski <mizdebsk@redhat.com> - 2.0-14
- Fix build-requires on apache-commons-parent

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Mar 04 2014 Stanislav Ochotnicky <sochotnicky@redhat.com> - 2.0-12
- Use Requires: java-headless rebuild (#1067528)

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Jun 28 2013 gil cattaneo <puntogil@libero.it> 2.0-10
- used pom_xpath_set macro

* Fri Jun 28 2013 gil cattaneo <puntogil@libero.it> 2.0-9
- swith to pom macros
- packaged in /usr/share/java instead of /usr/share/java/apache-commons-vfs

* Fri Jun 28 2013 Michal Srb <msrb@redhat.com> - 2.0-8
- Fix directory ownership

* Thu Jun 27 2013 Michal Srb <msrb@redhat.com> - 2.0-7
- Build with XMvn
- Do not ignore test failures
- Fix BR

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Feb 06 2013 Java SIG <java-devel@lists.fedoraproject.org> - 2.0-5
- Update for https://fedoraproject.org/wiki/Fedora_19_Maven_Rebuild
- Replace maven BuildRequires with maven-local

* Wed Aug  1 2012 Mikolaj Izdebski <mizdebsk@redhat.com> - 2.0-4
- Rebuild against javamail

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Jun 18 2012 gil cattaneo <puntogil@libero.it> 2.0-2
- add subpackage ant
- install NOTICE.txt in javadocs subpackage

* Mon May 14 2012 gil cattaneo <puntogil@libero.it> 2.0-1
- initial rpm
